
0.1.1
-----

- Fix a bug that prevented icon's title when flagging/unflagging using templates.
- Fix template to redirect unauthenticated users to login page when try to flag.
- Fix links in the readme on PyPi.




0.1.0
-----

First release
